Module: ActionController::HttpAuthentication::Basic

Extended by:
Basic
Included in:
Basic
Defined in:
lib/action_controller/http_authentication.rb

Overview

Makes it dead easy to do HTTP Basic authentication.

Simple Basic example:

class PostsController < ApplicationController
USER_NAME, PASSWORD = "dhh", "secret"

before_filter :authenticate, :except => [ :index ]

def index
  render :text => "Everyone can see me!"
end

def edit
  render :text => "I'm only accessible if you know the password"
end

private
  def authenticate
    authenticate_or_request_with_http_basic do |user_name, password| 
      user_name == USER_NAME && password == PASSWORD
    end
  end
end

Here is a more advanced Basic example where only Atom feeds and the XML API is protected by HTTP authentication, the regular HTML interface is protected by a session approach:

class ApplicationController < ActionController::Base
before_filter :set_account, :authenticate

protected
  def 
    @account = Account.find_by_url_name(request.subdomains.first)
  end

  def authenticate
    case request.format
    when Mime::XML, Mime::ATOM
      if user = authenticate_with_http_basic { |u, p| @account.users.authenticate(u, p) }
        @current_user = user
      else
        request_http_basic_authentication
      end
    else
      if session_authenticated?
        @current_user = @account.users.find(session[:authenticated][:user_id])
      else
        redirect_to() and return false
      end
    end
  end
end

In your integration tests, you can do something like this:

def test_access_granted_from_xml
get(
  "/notes/1.xml", nil, 
  :authorization => ActionController::HttpAuthentication::Basic.encode_credentials(users(:dhh).name, users(:dhh).password)
)

assert_equal 200, status
end

On shared hosts, Apache sometimes doesn't pass authentication headers to FCGI instances. If your environment matches this description and you cannot authenticate, try this rule in your Apache setup:

RewriteRule ^(.*)$ dispatch.fcgi [E=X-HTTP_AUTHORIZATION:%{HTTP:Authorization},QSA,L]

Defined Under Namespace

Modules: ControllerMethods

Instance Method Summary collapse

Instance Method Details

#authenticate(controller, &login_procedure) ⇒ Object



93
94
95
96
97
# File 'lib/action_controller/http_authentication.rb', line 93

def authenticate(controller, &)
  unless authorization(controller.request).blank?
    .call(*user_name_and_password(controller.request))
  end
end

#authentication_request(controller, realm) ⇒ Object



118
119
120
121
# File 'lib/action_controller/http_authentication.rb', line 118

def authentication_request(controller, realm)
  controller.headers["WWW-Authenticate"] = %(Basic realm="#{realm.gsub(/"/, "")}")
  controller.send! :render, :text => "HTTP Basic: Access denied.\n", :status => :unauthorized
end

#authorization(request) ⇒ Object



103
104
105
106
107
108
# File 'lib/action_controller/http_authentication.rb', line 103

def authorization(request)
  request.env['HTTP_AUTHORIZATION']   ||
  request.env['X-HTTP_AUTHORIZATION'] ||
  request.env['X_HTTP_AUTHORIZATION'] ||
  request.env['REDIRECT_X_HTTP_AUTHORIZATION']
end

#decode_credentials(request) ⇒ Object



110
111
112
# File 'lib/action_controller/http_authentication.rb', line 110

def decode_credentials(request)
  ActiveSupport::Base64.decode64(authorization(request).split.last || '')
end

#encode_credentials(user_name, password) ⇒ Object



114
115
116
# File 'lib/action_controller/http_authentication.rb', line 114

def encode_credentials(user_name, password)
  "Basic #{ActiveSupport::Base64.encode64("#{user_name}:#{password}")}"
end

#user_name_and_password(request) ⇒ Object



99
100
101
# File 'lib/action_controller/http_authentication.rb', line 99

def user_name_and_password(request)
  decode_credentials(request).split(/:/, 2)
end